Package: SPsimSeq
Title: Semi-parametric simulation tool for bulk and single-cell RNA
        sequencing data
Version: 1.23.0
Authors@R: 
    c(person(given = "Alemu Takele",
           family = "Assefa",
           role = c("aut"),
           email = "alemutak@hotmail.com"),
    person(given = "Olivier",
           family = "Thas",
           role = c("ths"),
           email = "Olivier.Thas@ugent.be"),
    person(given = "Joris",
           family = "Meys",
           role = c("cre"),
           email = "Joris.Meys@ugent.be"),
    person(given = "Stijn",
           family = "Hawinkel",
           role = c("aut"),
           email = "stijnhawinkel@hotmail.com"))
Description: SPsimSeq uses a specially designed exponential family for
        density estimation to constructs the distribution of gene
        expression levels from a given real RNA sequencing data
        (single-cell or bulk), and subsequently simulates a new dataset
        from the estimated marginal distributions using
        Gaussian-copulas to retain the dependence between genes. It
        allows simulation of multiple groups and batches with any
        required sample size and library size.
License: GPL-2
Encoding: UTF-8
LazyData: true
URL: https://github.com/CenterForStatistics-UGent/SPsimSeq
Imports: stats, methods, SingleCellExperiment, fitdistrplus, graphics,
        edgeR, Hmisc, WGCNA, limma, mvtnorm, phyloseq, utils
biocViews: GeneExpression, RNASeq, SingleCell, Sequencing, DNASeq
RoxygenNote: 7.1.0
Suggests: knitr, rmarkdown, LSD, testthat, BiocStyle
VignetteBuilder: knitr
Depends: R (>= 4.0)
Config/pak/sysreqs: cmake libglpk-dev make libicu-dev libuv1-dev
        libxml2-dev zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 12:52:57 UTC
RemoteUrl: https://github.com/bioc/SPsimSeq
RemoteRef: HEAD
RemoteSha: 72d88fe83edbdf2bcbcc993a08bdec977ca35ca3
NeedsCompilation: no
Packaged: 2026-05-30 09:48:31 UTC; root
Author: Alemu Takele Assefa [aut],
  Olivier Thas [ths],
  Joris Meys [cre],
  Stijn Hawinkel [aut]
Maintainer: Joris Meys <Joris.Meys@ugent.be>
Built: R 4.6.0; ; 2026-05-30 14:48:01 UTC; unix
