# Generated by roxygen2: do not edit by hand

export(SPsimSeq)
export(configExperiment)
export(evaluateDensities)
import(methods)
importFrom(Hmisc,cut2)
importFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(SingleCellExperiment,counts)
importFrom(WGCNA,cor)
importFrom(edgeR,calcNormFactors)
importFrom(fitdistrplus,fitdist)
importFrom(graphics,hist)
importFrom(limma,voom)
importFrom(mvtnorm,rmvnorm)
importFrom(phyloseq,otu_table)
importFrom(phyloseq,t)
importFrom(phyloseq,taxa_are_rows)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,glm)
importFrom(stats,glm.fit)
importFrom(stats,lm)
importFrom(stats,model.matrix)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,rbinom)
importFrom(stats,rlnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(utils,combn)
