% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genCopula.R
\name{genCopula}
\alias{genCopula}
\title{Generate a copula instance}
\usage{
genCopula(corMats, exprmt.design)
}
\arguments{
\item{corMats}{List of correlation matrices}

\item{exprmt.design}{Number of batches, and batch vector}
}
\value{
a list of copula instances
}
\description{
Generate a copula instance
}
