% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/samZeroID.R
\name{expit}
\alias{expit}
\title{Evaluate the expit function}
\usage{
expit(x)
}
\arguments{
\item{x}{the argument}
}
\value{
the expit of the argument
}
\description{
Evaluate the expit function
}
